==> istio-model-v1alpha3-6.2.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HTTPFaultInjectionAbortFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Double;
import java.lang.Integer;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPFaultInjectionAbortFluentImpl<A extends HTTPFaultInjectionAbortFluent<A>> extends BaseFluent<A> implements HTTPFaultInjectionAbortFluent<A>{
  public HTTPFaultInjectionAbortFluentImpl() {
  }
  public HTTPFaultInjectionAbortFluentImpl(HTTPFaultInjectionAbort instance) {
    this.withErrorType(instance.getErrorType()); 
    this.withPercentage(instance.getPercentage()); 
  }
  private VisitableBuilder<? extends IsHTTPFaultInjectionAbortErrorType,?> errorType;
  private PercentBuilder percentage;
  
  /**
   * This method has been deprecated, please use method buildErrorType instead.
   * @return The buildable object.
   */
  @Deprecated
  public IsHTTPFaultInjectionAbortErrorType getErrorType() {
    return this.errorType!=null?this.errorType.build():null;
  }
  public IsHTTPFaultInjectionAbortErrorType buildErrorType() {
    return this.errorType!=null?this.errorType.build():null;
  }
  public A withErrorType(IsHTTPFaultInjectionAbortErrorType errorType) {
    if (errorType instanceof HTTPFaultInjectionAbortHttpStatus){ this.errorType= new HTTPFaultInjectionAbortHttpStatusBuilder((HTTPFaultInjectionAbortHttpStatus)errorType); _visitables.get("errorType").add(this.errorType);}
    if (errorType instanceof HTTPFaultInjectionAbortHttp2Error){ this.errorType= new HTTPFaultInjectionAbortHttp2ErrorBuilder((HTTPFaultInjectionAbortHttp2Error)errorType); _visitables.get("errorType").add(this.errorType);}
    if (errorType instanceof HTTPFaultInjectionAbortGrpcStatus){ this.errorType= new HTTPFaultInjectionAbortGrpcStatusBuilder((HTTPFaultInjectionAbortGrpcStatus)errorType); _visitables.get("errorType").add(this.errorType);}
    return (A) this;
  }
  public Boolean hasErrorType() {
    return this.errorType != null;
  }
  public A withHTTPFaultInjectionAbortHttpStatusErrorType(HTTPFaultInjectionAbortHttpStatus hTTPFaultInjectionAbortHttpStatusErrorType) {
    _visitables.get("errorType").remove(this.errorType);
    if (hTTPFaultInjectionAbortHttpStatusErrorType!=null){ this.errorType= new HTTPFaultInjectionAbortHttpStatusBuilder(hTTPFaultInjectionAbortHttpStatusErrorType); _visitables.get("errorType").add(this.errorType);} else { this.errorType = null; _visitables.get("errorType").remove(this.errorType); } return (A) this;
  }
  public HTTPFaultInjectionAbortFluent.HTTPFaultInjectionAbortHttpStatusErrorTypeNested<A> withNewHTTPFaultInjectionAbortHttpStatusErrorType() {
    return new HTTPFaultInjectionAbortFluentImpl.HTTPFaultInjectionAbortHttpStatusErrorTypeNestedImpl();
  }
  public HTTPFaultInjectionAbortFluent.HTTPFaultInjectionAbortHttpStatusErrorTypeNested<A> withNewHTTPFaultInjectionAbortHttpStatusErrorTypeLike(HTTPFaultInjectionAbortHttpStatus item) {
    return new HTTPFaultInjectionAbortFluentImpl.HTTPFaultInjectionAbortHttpStatusErrorTypeNestedImpl(item);
  }
  public A withNewHTTPFaultInjectionAbortHttpStatusErrorType(Integer httpStatus) {
    return (A)withHTTPFaultInjectionAbortHttpStatusErrorType(new HTTPFaultInjectionAbortHttpStatus(httpStatus));
  }
  public A withHTTPFaultInjectionAbortHttp2ErrorType(HTTPFaultInjectionAbortHttp2Error hTTPFaultInjectionAbortHttp2ErrorType) {
    _visitables.get("errorType").remove(this.errorType);
    if (hTTPFaultInjectionAbortHttp2ErrorType!=null){ this.errorType= new HTTPFaultInjectionAbortHttp2ErrorBuilder(hTTPFaultInjectionAbortHttp2ErrorType); _visitables.get("errorType").add(this.errorType);} else { this.errorType = null; _visitables.get("errorType").remove(this.errorType); } return (A) this;
  }
  public HTTPFaultInjectionAbortFluent.HTTPFaultInjectionAbortHttp2ErrorTypeNested<A> withNewHTTPFaultInjectionAbortHttp2ErrorType() {
    return new HTTPFaultInjectionAbortFluentImpl.HTTPFaultInjectionAbortHttp2ErrorTypeNestedImpl();
  }
  public HTTPFaultInjectionAbortFluent.HTTPFaultInjectionAbortHttp2ErrorTypeNested<A> withNewHTTPFaultInjectionAbortHttp2ErrorTypeLike(HTTPFaultInjectionAbortHttp2Error item) {
    return new HTTPFaultInjectionAbortFluentImpl.HTTPFaultInjectionAbortHttp2ErrorTypeNestedImpl(item);
  }
  public A withNewHTTPFaultInjectionAbortHttp2ErrorType(String http2Error) {
    return (A)withHTTPFaultInjectionAbortHttp2ErrorType(new HTTPFaultInjectionAbortHttp2Error(http2Error));
  }
  public A withHTTPFaultInjectionAbortGrpcStatusErrorType(HTTPFaultInjectionAbortGrpcStatus hTTPFaultInjectionAbortGrpcStatusErrorType) {
    _visitables.get("errorType").remove(this.errorType);
    if (hTTPFaultInjectionAbortGrpcStatusErrorType!=null){ this.errorType= new HTTPFaultInjectionAbortGrpcStatusBuilder(hTTPFaultInjectionAbortGrpcStatusErrorType); _visitables.get("errorType").add(this.errorType);} else { this.errorType = null; _visitables.get("errorType").remove(this.errorType); } return (A) this;
  }
  public HTTPFaultInjectionAbortFluent.HTTPFaultInjectionAbortGrpcStatusErrorTypeNested<A> withNewHTTPFaultInjectionAbortGrpcStatusErrorType() {
    return new HTTPFaultInjectionAbortFluentImpl.HTTPFaultInjectionAbortGrpcStatusErrorTypeNestedImpl();
  }
  public HTTPFaultInjectionAbortFluent.HTTPFaultInjectionAbortGrpcStatusErrorTypeNested<A> withNewHTTPFaultInjectionAbortGrpcStatusErrorTypeLike(HTTPFaultInjectionAbortGrpcStatus item) {
    return new HTTPFaultInjectionAbortFluentImpl.HTTPFaultInjectionAbortGrpcStatusErrorTypeNestedImpl(item);
  }
  public A withNewHTTPFaultInjectionAbortGrpcStatusErrorType(String grpcStatus) {
    return (A)withHTTPFaultInjectionAbortGrpcStatusErrorType(new HTTPFaultInjectionAbortGrpcStatus(grpcStatus));
  }
  
  /**
   * This method has been deprecated, please use method buildPercentage instead.
   * @return The buildable object.
   */
  @Deprecated
  public Percent getPercentage() {
    return this.percentage!=null ?this.percentage.build():null;
  }
  public Percent buildPercentage() {
    return this.percentage!=null ?this.percentage.build():null;
  }
  public A withPercentage(Percent percentage) {
    _visitables.get("percentage").remove(this.percentage);
    if (percentage!=null){ this.percentage= new PercentBuilder(percentage); _visitables.get("percentage").add(this.percentage);} else { this.percentage = null; _visitables.get("percentage").remove(this.percentage); } return (A) this;
  }
  public Boolean hasPercentage() {
    return this.percentage != null;
  }
  public A withNewPercentage(Double value) {
    return (A)withPercentage(new Percent(value));
  }
  public HTTPFaultInjectionAbortFluent.PercentageNested<A> withNewPercentage() {
    return new HTTPFaultInjectionAbortFluentImpl.PercentageNestedImpl();
  }
  public HTTPFaultInjectionAbortFluent.PercentageNested<A> withNewPercentageLike(Percent item) {
    return new HTTPFaultInjectionAbortFluentImpl.PercentageNestedImpl(item);
  }
  public HTTPFaultInjectionAbortFluent.PercentageNested<A> editPercentage() {
    return withNewPercentageLike(getPercentage());
  }
  public HTTPFaultInjectionAbortFluent.PercentageNested<A> editOrNewPercentage() {
    return withNewPercentageLike(getPercentage() != null ? getPercentage(): new PercentBuilder().build());
  }
  public HTTPFaultInjectionAbortFluent.PercentageNested<A> editOrNewPercentageLike(Percent item) {
    return withNewPercentageLike(getPercentage() != null ? getPercentage(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HTTPFaultInjectionAbortFluentImpl that = (HTTPFaultInjectionAbortFluentImpl) o;
    if (errorType != null ? !errorType.equals(that.errorType) :that.errorType != null) return false;
    if (percentage != null ? !percentage.equals(that.percentage) :that.percentage != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(errorType,  percentage,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (errorType != null) { sb.append("errorType:"); sb.append(errorType + ","); }
    if (percentage != null) { sb.append("percentage:"); sb.append(percentage); }
    sb.append("}");
    return sb.toString();
  }
  class HTTPFaultInjectionAbortHttpStatusErrorTypeNestedImpl<N> extends HTTPFaultInjectionAbortHttpStatusFluentImpl<HTTPFaultInjectionAbortFluent.HTTPFaultInjectionAbortHttpStatusErrorTypeNested<N>> implements HTTPFaultInjectionAbortFluent.HTTPFaultInjectionAbortHttpStatusErrorTypeNested<N>,Nested<N>{
    HTTPFaultInjectionAbortHttpStatusErrorTypeNestedImpl(HTTPFaultInjectionAbortHttpStatus item) {
      this.builder = new HTTPFaultInjectionAbortHttpStatusBuilder(this, item);
    }
    HTTPFaultInjectionAbortHttpStatusErrorTypeNestedImpl() {
      this.builder = new HTTPFaultInjectionAbortHttpStatusBuilder(this);
    }
    HTTPFaultInjectionAbortHttpStatusBuilder builder;
    public N and() {
      return (N) HTTPFaultInjectionAbortFluentImpl.this.withErrorType(builder.build());
    }
    public N endHTTPFaultInjectionAbortHttpStatusErrorType() {
      return and();
    }
    
  }
  class HTTPFaultInjectionAbortHttp2ErrorTypeNestedImpl<N> extends HTTPFaultInjectionAbortHttp2ErrorFluentImpl<HTTPFaultInjectionAbortFluent.HTTPFaultInjectionAbortHttp2ErrorTypeNested<N>> implements HTTPFaultInjectionAbortFluent.HTTPFaultInjectionAbortHttp2ErrorTypeNested<N>,Nested<N>{
    HTTPFaultInjectionAbortHttp2ErrorTypeNestedImpl(HTTPFaultInjectionAbortHttp2Error item) {
      this.builder = new HTTPFaultInjectionAbortHttp2ErrorBuilder(this, item);
    }
    HTTPFaultInjectionAbortHttp2ErrorTypeNestedImpl() {
      this.builder = new HTTPFaultInjectionAbortHttp2ErrorBuilder(this);
    }
    HTTPFaultInjectionAbortHttp2ErrorBuilder builder;
    public N and() {
      return (N) HTTPFaultInjectionAbortFluentImpl.this.withErrorType(builder.build());
    }
    public N endHTTPFaultInjectionAbortHttp2ErrorType() {
      return and();
    }
    
  }
  class HTTPFaultInjectionAbortGrpcStatusErrorTypeNestedImpl<N> extends HTTPFaultInjectionAbortGrpcStatusFluentImpl<HTTPFaultInjectionAbortFluent.HTTPFaultInjectionAbortGrpcStatusErrorTypeNested<N>> implements HTTPFaultInjectionAbortFluent.HTTPFaultInjectionAbortGrpcStatusErrorTypeNested<N>,Nested<N>{
    HTTPFaultInjectionAbortGrpcStatusErrorTypeNestedImpl(HTTPFaultInjectionAbortGrpcStatus item) {
      this.builder = new HTTPFaultInjectionAbortGrpcStatusBuilder(this, item);
    }
    HTTPFaultInjectionAbortGrpcStatusErrorTypeNestedImpl() {
      this.builder = new HTTPFaultInjectionAbortGrpcStatusBuilder(this);
    }
    HTTPFaultInjectionAbortGrpcStatusBuilder builder;
    public N and() {
      return (N) HTTPFaultInjectionAbortFluentImpl.this.withErrorType(builder.build());
    }
    public N endHTTPFaultInjectionAbortGrpcStatusErrorType() {
      return and();
    }
    
  }
  class PercentageNestedImpl<N> extends PercentFluentImpl<HTTPFaultInjectionAbortFluent.PercentageNested<N>> implements HTTPFaultInjectionAbortFluent.PercentageNested<N>,Nested<N>{
    PercentageNestedImpl(Percent item) {
      this.builder = new PercentBuilder(this, item);
    }
    PercentageNestedImpl() {
      this.builder = new PercentBuilder(this);
    }
    PercentBuilder builder;
    public N and() {
      return (N) HTTPFaultInjectionAbortFluentImpl.this.withPercentage(builder.build());
    }
    public N endPercentage() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HTTPFaultInjectionAbortFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Double;
import java.lang.Integer;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPFaultInjectionAbortFluentImpl<A extends HTTPFaultInjectionAbortFluent<A>> extends BaseFluent<A> implements HTTPFaultInjectionAbortFluent<A>{
  public HTTPFaultInjectionAbortFluentImpl() {
  }
  public HTTPFaultInjectionAbortFluentImpl(HTTPFaultInjectionAbort instance) {
    if (instance != null) {
      this.withErrorType(instance.getErrorType());
      this.withPercentage(instance.getPercentage());
    }
  }
  private VisitableBuilder<? extends IsHTTPFaultInjectionAbortErrorType,?> errorType;
  private PercentBuilder percentage;
  
  /**
   * This method has been deprecated, please use method buildErrorType instead.
   * @return The buildable object.
   */
  @Deprecated
  public IsHTTPFaultInjectionAbortErrorType getErrorType() {
    return this.errorType!=null?this.errorType.build():null;
  }
  public IsHTTPFaultInjectionAbortErrorType buildErrorType() {
    return this.errorType!=null?this.errorType.build():null;
  }
  public A withErrorType(IsHTTPFaultInjectionAbortErrorType errorType) {
    if (errorType==null){ this.errorType = null; _visitables.remove("errorType"); return (A) this;}
    if (errorType instanceof HTTPFaultInjectionAbortHttpStatus){ this.errorType= new HTTPFaultInjectionAbortHttpStatusBuilder((HTTPFaultInjectionAbortHttpStatus)errorType); _visitables.get("errorType").clear(); _visitables.get("errorType").add(this.errorType);}
    if (errorType instanceof HTTPFaultInjectionAbortHttp2Error){ this.errorType= new HTTPFaultInjectionAbortHttp2ErrorBuilder((HTTPFaultInjectionAbortHttp2Error)errorType); _visitables.get("errorType").clear(); _visitables.get("errorType").add(this.errorType);}
    if (errorType instanceof HTTPFaultInjectionAbortGrpcStatus){ this.errorType= new HTTPFaultInjectionAbortGrpcStatusBuilder((HTTPFaultInjectionAbortGrpcStatus)errorType); _visitables.get("errorType").clear(); _visitables.get("errorType").add(this.errorType);}
    VisitableBuilder<? extends IsHTTPFaultInjectionAbortErrorType,?> builder = builderOf(errorType); _visitables.get("errorType").clear();_visitables.get("errorType").add(builder);this.errorType = builder;
    return (A) this;
  }
  public Boolean hasErrorType() {
    return this.errorType != null;
  }
  public A withHTTPFaultInjectionAbortHttpStatusErrorType(HTTPFaultInjectionAbortHttpStatus hTTPFaultInjectionAbortHttpStatusErrorType) {
    _visitables.get("errorType").remove(this.errorType);
    if (hTTPFaultInjectionAbortHttpStatusErrorType!=null){ this.errorType= new HTTPFaultInjectionAbortHttpStatusBuilder(hTTPFaultInjectionAbortHttpStatusErrorType); _visitables.get("errorType").add(this.errorType);} else { this.errorType = null; _visitables.get("errorType").remove(this.errorType); } return (A) this;
  }
  public HTTPFaultInjectionAbortFluentImpl.HTTPFaultInjectionAbortHttpStatusErrorTypeNested<A> withNewHTTPFaultInjectionAbortHttpStatusErrorType() {
    return new HTTPFaultInjectionAbortFluentImpl.HTTPFaultInjectionAbortHttpStatusErrorTypeNestedImpl();
  }
  public HTTPFaultInjectionAbortFluentImpl.HTTPFaultInjectionAbortHttpStatusErrorTypeNested<A> withNewHTTPFaultInjectionAbortHttpStatusErrorTypeLike(HTTPFaultInjectionAbortHttpStatus item) {
    return new HTTPFaultInjectionAbortFluentImpl.HTTPFaultInjectionAbortHttpStatusErrorTypeNestedImpl(item);
  }
  public A withNewHTTPFaultInjectionAbortHttpStatusErrorType(Integer httpStatus) {
    return (A)withHTTPFaultInjectionAbortHttpStatusErrorType(new HTTPFaultInjectionAbortHttpStatus(httpStatus));
  }
  public A withHTTPFaultInjectionAbortHttp2ErrorType(HTTPFaultInjectionAbortHttp2Error hTTPFaultInjectionAbortHttp2ErrorType) {
    _visitables.get("errorType").remove(this.errorType);
    if (hTTPFaultInjectionAbortHttp2ErrorType!=null){ this.errorType= new HTTPFaultInjectionAbortHttp2ErrorBuilder(hTTPFaultInjectionAbortHttp2ErrorType); _visitables.get("errorType").add(this.errorType);} else { this.errorType = null; _visitables.get("errorType").remove(this.errorType); } return (A) this;
  }
  public HTTPFaultInjectionAbortFluentImpl.HTTPFaultInjectionAbortHttp2ErrorTypeNested<A> withNewHTTPFaultInjectionAbortHttp2ErrorType() {
    return new HTTPFaultInjectionAbortFluentImpl.HTTPFaultInjectionAbortHttp2ErrorTypeNestedImpl();
  }
  public HTTPFaultInjectionAbortFluentImpl.HTTPFaultInjectionAbortHttp2ErrorTypeNested<A> withNewHTTPFaultInjectionAbortHttp2ErrorTypeLike(HTTPFaultInjectionAbortHttp2Error item) {
    return new HTTPFaultInjectionAbortFluentImpl.HTTPFaultInjectionAbortHttp2ErrorTypeNestedImpl(item);
  }
  public A withNewHTTPFaultInjectionAbortHttp2ErrorType(String http2Error) {
    return (A)withHTTPFaultInjectionAbortHttp2ErrorType(new HTTPFaultInjectionAbortHttp2Error(http2Error));
  }
  public A withHTTPFaultInjectionAbortGrpcStatusErrorType(HTTPFaultInjectionAbortGrpcStatus hTTPFaultInjectionAbortGrpcStatusErrorType) {
    _visitables.get("errorType").remove(this.errorType);
    if (hTTPFaultInjectionAbortGrpcStatusErrorType!=null){ this.errorType= new HTTPFaultInjectionAbortGrpcStatusBuilder(hTTPFaultInjectionAbortGrpcStatusErrorType); _visitables.get("errorType").add(this.errorType);} else { this.errorType = null; _visitables.get("errorType").remove(this.errorType); } return (A) this;
  }
  public HTTPFaultInjectionAbortFluentImpl.HTTPFaultInjectionAbortGrpcStatusErrorTypeNested<A> withNewHTTPFaultInjectionAbortGrpcStatusErrorType() {
    return new HTTPFaultInjectionAbortFluentImpl.HTTPFaultInjectionAbortGrpcStatusErrorTypeNestedImpl();
  }
  public HTTPFaultInjectionAbortFluentImpl.HTTPFaultInjectionAbortGrpcStatusErrorTypeNested<A> withNewHTTPFaultInjectionAbortGrpcStatusErrorTypeLike(HTTPFaultInjectionAbortGrpcStatus item) {
    return new HTTPFaultInjectionAbortFluentImpl.HTTPFaultInjectionAbortGrpcStatusErrorTypeNestedImpl(item);
  }
  public A withNewHTTPFaultInjectionAbortGrpcStatusErrorType(String grpcStatus) {
    return (A)withHTTPFaultInjectionAbortGrpcStatusErrorType(new HTTPFaultInjectionAbortGrpcStatus(grpcStatus));
  }
  
  /**
   * This method has been deprecated, please use method buildPercentage instead.
   * @return The buildable object.
   */
  @Deprecated
  public Percent getPercentage() {
    return this.percentage!=null ?this.percentage.build():null;
  }
  public Percent buildPercentage() {
    return this.percentage!=null ?this.percentage.build():null;
  }
  public A withPercentage(Percent percentage) {
    _visitables.get("percentage").remove(this.percentage);
    if (percentage!=null){ this.percentage= new PercentBuilder(percentage); _visitables.get("percentage").add(this.percentage);} else { this.percentage = null; _visitables.get("percentage").remove(this.percentage); } return (A) this;
  }
  public Boolean hasPercentage() {
    return this.percentage != null;
  }
  public A withNewPercentage(Double value) {
    return (A)withPercentage(new Percent(value));
  }
  public HTTPFaultInjectionAbortFluentImpl.PercentageNested<A> withNewPercentage() {
    return new HTTPFaultInjectionAbortFluentImpl.PercentageNestedImpl();
  }
  public HTTPFaultInjectionAbortFluentImpl.PercentageNested<A> withNewPercentageLike(Percent item) {
    return new HTTPFaultInjectionAbortFluentImpl.PercentageNestedImpl(item);
  }
  public HTTPFaultInjectionAbortFluentImpl.PercentageNested<A> editPercentage() {
    return withNewPercentageLike(getPercentage());
  }
  public HTTPFaultInjectionAbortFluentImpl.PercentageNested<A> editOrNewPercentage() {
    return withNewPercentageLike(getPercentage() != null ? getPercentage(): new PercentBuilder().build());
  }
  public HTTPFaultInjectionAbortFluentImpl.PercentageNested<A> editOrNewPercentageLike(Percent item) {
    return withNewPercentageLike(getPercentage() != null ? getPercentage(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPFaultInjectionAbortFluentImpl that = (HTTPFaultInjectionAbortFluentImpl) o;
    if (!java.util.Objects.equals(errorType, that.errorType)) return false;

    if (!java.util.Objects.equals(percentage, that.percentage)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(errorType,  percentage,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (errorType != null) { sb.append("errorType:"); sb.append(errorType + ","); }
    if (percentage != null) { sb.append("percentage:"); sb.append(percentage); }
    sb.append("}");
    return sb.toString();
  }
  class HTTPFaultInjectionAbortHttpStatusErrorTypeNestedImpl<N> extends HTTPFaultInjectionAbortHttpStatusFluentImpl<HTTPFaultInjectionAbortFluentImpl.HTTPFaultInjectionAbortHttpStatusErrorTypeNested<N>> implements HTTPFaultInjectionAbortFluentImpl.HTTPFaultInjectionAbortHttpStatusErrorTypeNested<N>,Nested<N>{
    HTTPFaultInjectionAbortHttpStatusErrorTypeNestedImpl(HTTPFaultInjectionAbortHttpStatus item) {
      this.builder = new HTTPFaultInjectionAbortHttpStatusBuilder(this, item);
    }
    HTTPFaultInjectionAbortHttpStatusErrorTypeNestedImpl() {
      this.builder = new HTTPFaultInjectionAbortHttpStatusBuilder(this);
    }
    HTTPFaultInjectionAbortHttpStatusBuilder builder;
    public N and() {
      return (N) HTTPFaultInjectionAbortFluentImpl.this.withErrorType(builder.build());
    }
    public N endHTTPFaultInjectionAbortHttpStatusErrorType() {
      return and();
    }
    
  }
  class HTTPFaultInjectionAbortHttp2ErrorTypeNestedImpl<N> extends HTTPFaultInjectionAbortHttp2ErrorFluentImpl<HTTPFaultInjectionAbortFluentImpl.HTTPFaultInjectionAbortHttp2ErrorTypeNested<N>> implements HTTPFaultInjectionAbortFluentImpl.HTTPFaultInjectionAbortHttp2ErrorTypeNested<N>,Nested<N>{
    HTTPFaultInjectionAbortHttp2ErrorTypeNestedImpl(HTTPFaultInjectionAbortHttp2Error item) {
      this.builder = new HTTPFaultInjectionAbortHttp2ErrorBuilder(this, item);
    }
    HTTPFaultInjectionAbortHttp2ErrorTypeNestedImpl() {
      this.builder = new HTTPFaultInjectionAbortHttp2ErrorBuilder(this);
    }
    HTTPFaultInjectionAbortHttp2ErrorBuilder builder;
    public N and() {
      return (N) HTTPFaultInjectionAbortFluentImpl.this.withErrorType(builder.build());
    }
    public N endHTTPFaultInjectionAbortHttp2ErrorType() {
      return and();
    }
    
  }
  class HTTPFaultInjectionAbortGrpcStatusErrorTypeNestedImpl<N> extends HTTPFaultInjectionAbortGrpcStatusFluentImpl<HTTPFaultInjectionAbortFluentImpl.HTTPFaultInjectionAbortGrpcStatusErrorTypeNested<N>> implements HTTPFaultInjectionAbortFluentImpl.HTTPFaultInjectionAbortGrpcStatusErrorTypeNested<N>,Nested<N>{
    HTTPFaultInjectionAbortGrpcStatusErrorTypeNestedImpl(HTTPFaultInjectionAbortGrpcStatus item) {
      this.builder = new HTTPFaultInjectionAbortGrpcStatusBuilder(this, item);
    }
    HTTPFaultInjectionAbortGrpcStatusErrorTypeNestedImpl() {
      this.builder = new HTTPFaultInjectionAbortGrpcStatusBuilder(this);
    }
    HTTPFaultInjectionAbortGrpcStatusBuilder builder;
    public N and() {
      return (N) HTTPFaultInjectionAbortFluentImpl.this.withErrorType(builder.build());
    }
    public N endHTTPFaultInjectionAbortGrpcStatusErrorType() {
      return and();
    }
    
  }
  class PercentageNestedImpl<N> extends PercentFluentImpl<HTTPFaultInjectionAbortFluentImpl.PercentageNested<N>> implements HTTPFaultInjectionAbortFluentImpl.PercentageNested<N>,Nested<N>{
    PercentageNestedImpl(Percent item) {
      this.builder = new PercentBuilder(this, item);
    }
    PercentageNestedImpl() {
      this.builder = new PercentBuilder(this);
    }
    PercentBuilder builder;
    public N and() {
      return (N) HTTPFaultInjectionAbortFluentImpl.this.withPercentage(builder.build());
    }
    public N endPercentage() {
      return and();
    }
    
  }
  
}
